@@ -25,25 +25,37 @@ import six
 from octavia.amphorae.backends.agent.api_server import util
 from octavia.amphorae.backends.health_daemon import health_sender
 from octavia.amphorae.backends.utils import haproxy_query
+from octavia.amphorae.backends.utils import keepalivedlvs_query
+
 
 if six.PY2:
-    import Queue as queue
+    import Queue as queue  # pylint: disable=wrong-import-order
 else:
-    import queue
+    import queue  # pylint: disable=wrong-import-order
+
 
 CONF = cfg.CONF
 LOG = logging.getLogger(__name__)
 SEQ = 0
+# MSG_VER is an incrementing integer heartbeat message format version
+# this allows for backward compatibility when the amphora-agent is older
+# than the controller version and the message format has backwards
+# incompatible changes.
+#
+# ver 1 - Adds UDP listener status when no pool or members are present
+# ver 2 - Switch to all listeners in a single combined haproxy config
+#
+MSG_VER = 2
 
 
 def list_sock_stat_files(hadir=None):
     stat_sock_files = {}
     if hadir is None:
         hadir = CONF.haproxy_amphora.base_path
-    listener_ids = util.get_listeners()
-    for listener_id in listener_ids:
-        sock_file = listener_id + ".sock"
-        stat_sock_files[listener_id] = os.path.join(hadir, sock_file)
+    lb_ids = util.get_loadbalancers()
+    for lb_id in lb_ids:
+        sock_file = lb_id + ".sock"
+        stat_sock_files[lb_id] = os.path.join(hadir, sock_file)
     return stat_sock_files
 
 
@@ -91,10 +103,10 @@ def run_sender(cmd_queue):
 
         try:
             cmd = cmd_queue.get_nowait()
-            if cmd is 'reload':
+            if cmd == 'reload':
                 LOG.info('Reloading configuration')
                 CONF.reload_config_files()
-            elif cmd is 'shutdown':
+            elif cmd == 'shutdown':
                 LOG.info('Health Manager Sender shutting down.')
                 break
         except queue.Empty:
@@ -110,36 +122,78 @@ def get_stats(stat_sock_file):
 
 
 def build_stats_message():
+    # Example version 2 message without UDP:
+    # {
+    #   "id": "<amphora_id>",
+    #   "seq": 67,
+    #   "listeners": {
+    #     "<listener_id>": {
+    #       "status": "OPEN",
+    #       "stats": {
+    #         "tx": 0,
+    #         "rx": 0,
+    #         "conns": 0,
+    #         "totconns": 0,
+    #         "ereq": 0
+    #       }
+    #     }
+    #  },
+    #  "pools": {
+    #    "<pool_id>:<listener_id>": {
+    #      "status": "UP",
+    #      "members": {
+    #        "<member_id>": "no check"
+    #      }
+    #    }
+    #  },
+    #  "ver": 2
+    # }
     global SEQ
     msg = {'id': CONF.amphora_agent.amphora_id,
-           'seq': SEQ, "listeners": {}}
+           'seq': SEQ, 'listeners': {}, 'pools': {},
+           'ver': MSG_VER}
     SEQ += 1
     stat_sock_files = list_sock_stat_files()
-    for listener_id, stat_sock_file in stat_sock_files.items():
-        listener_dict = {'pools': {},
-                         'status': 'DOWN',
-                         'stats': {
-                             'tx': 0,
-                             'rx': 0,
-                             'conns': 0,
-                             'totconns': 0,
-                             'ereq': 0}}
-        msg['listeners'][listener_id] = listener_dict
-        if util.is_listener_running(listener_id):
+    # TODO(rm_work) There should only be one of these in the new config system
+    for lb_id, stat_sock_file in stat_sock_files.items():
+        if util.is_lb_running(lb_id):
             (stats, pool_status) = get_stats(stat_sock_file)
-            listener_dict = msg['listeners'][listener_id]
             for row in stats:
                 if row['svname'] == 'FRONTEND':
-                    listener_dict['stats']['tx'] = int(row['bout'])
-                    listener_dict['stats']['rx'] = int(row['bin'])
-                    listener_dict['stats']['conns'] = int(row['scur'])
-                    listener_dict['stats']['totconns'] = int(row['stot'])
-                    listener_dict['stats']['ereq'] = int(row['ereq'])
-                    listener_dict['status'] = row['status']
-            for oid, pool in pool_status.items():
-                if oid != listener_id:
-                    pool_id = oid
-                    pools = listener_dict['pools']
-                    pools[pool_id] = {"status": pool['status'],
-                                      "members": pool['members']}
+                    listener_id = row['pxname']
+                    msg['listeners'][listener_id] = {
+                        'status': row['status'],
+                        'stats': {'tx': int(row['bout']),
+                                  'rx': int(row['bin']),
+                                  'conns': int(row['scur']),
+                                  'totconns': int(row['stot']),
+                                  'ereq': int(row['ereq'])}}
+            for pool_id, pool in pool_status.items():
+                msg['pools'][pool_id] = {"status": pool['status'],
+                                         "members": pool['members']}
+
+    # UDP listener part
+    udp_listener_ids = util.get_udp_listeners()
+    if udp_listener_ids:
+        listeners_stats = keepalivedlvs_query.get_udp_listeners_stats()
+        if listeners_stats:
+            for listener_id, listener_stats in listeners_stats.items():
+                pool_status = keepalivedlvs_query.get_udp_listener_pool_status(
+                    listener_id)
+                udp_listener_dict = dict()
+                udp_listener_dict['status'] = listener_stats['status']
+                udp_listener_dict['stats'] = {
+                    'tx': listener_stats['stats']['bout'],
+                    'rx': listener_stats['stats']['bin'],
+                    'conns': listener_stats['stats']['scur'],
+                    'totconns': listener_stats['stats']['stot'],
+                    'ereq': listener_stats['stats']['ereq']
+                }
+                if pool_status:
+                    pool_id = pool_status['lvs']['uuid']
+                    msg['pools'][pool_id] = {
+                        "status": pool_status['lvs']['status'],
+                        "members": pool_status['lvs']['members']
+                    }
+                msg['listeners'][listener_id] = udp_listener_dict
     return msg
