@@ -12,8 +12,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import six
+
 from oslo_utils import excutils
 
+from octavia.i18n import _
+
 
 class AmphoraDriverError(Exception):
 
@@ -31,8 +35,7 @@ class AmphoraDriverError(Exception):
                     super(AmphoraDriverError, self).__init__(self.message)
 
     def __unicode__(self):
-
-        return unicode(self.msg)
+        return six.text_type(self.msg)
 
     @staticmethod
     def use_fatal_exceptions():
@@ -113,3 +116,8 @@ class HealthMonitorProvisioningError(ProvisioningErrors):
 class NodeProvisioningError(ProvisioningErrors):
 
     message = _('couldn\'t provision Node')
+
+
+class AmpDriverNotImplementedError(AmphoraDriverError):
+
+    message = _('Amphora does not implement this feature.')
