@@ -75,6 +75,29 @@ class RootController(rest.RestController):
                                 '2016-12-11T00:00:00Z', host_url)
             self._add_a_version(versions, 'v2.1', 'v2', 'SUPPORTED',
                                 '2018-04-20T00:00:00Z', host_url)
-            self._add_a_version(versions, 'v2.2', 'v2', 'CURRENT',
+            self._add_a_version(versions, 'v2.2', 'v2', 'SUPPORTED',
                                 '2018-07-31T00:00:00Z', host_url)
+            self._add_a_version(versions, 'v2.3', 'v2', 'SUPPORTED',
+                                '2018-12-18T00:00:00Z', host_url)
+            # amp statistics
+            self._add_a_version(versions, 'v2.4', 'v2', 'SUPPORTED',
+                                '2018-12-19T00:00:00Z', host_url)
+            # Tags
+            self._add_a_version(versions, 'v2.5', 'v2', 'SUPPORTED',
+                                '2019-01-21T00:00:00Z', host_url)
+            # Flavors
+            self._add_a_version(versions, 'v2.6', 'v2', 'SUPPORTED',
+                                '2019-01-25T00:00:00Z', host_url)
+            # Amphora Config update
+            self._add_a_version(versions, 'v2.7', 'v2', 'SUPPORTED',
+                                '2018-01-25T12:00:00Z', host_url)
+            # TLS client authentication
+            self._add_a_version(versions, 'v2.8', 'v2', 'SUPPORTED',
+                                '2019-02-12T00:00:00Z', host_url)
+            # HTTP Redirect code
+            self._add_a_version(versions, 'v2.9', 'v2', 'SUPPORTED',
+                                '2019-03-04T00:00:00Z', host_url)
+            # Healthmonitor host header
+            self._add_a_version(versions, 'v2.10', 'v2', 'CURRENT',
+                                '2019-03-05T00:00:00Z', host_url)
         return {'versions': versions}
