@@ -145,12 +145,6 @@ class MemberController(base.BaseController):
         member = member_.member
         context = pecan.request.context.get('octavia_context')
 
-        validate.ip_not_reserved(member.address)
-
-        # Validate member subnet
-        if member.subnet_id and not validate.subnet_exists(member.subnet_id):
-            raise exceptions.NotFound(resource='Subnet',
-                                      id=member.subnet_id)
         pool = self.repositories.pool.get(context.session, id=self.pool_id)
         member.project_id, provider = self._get_lb_project_id_provider(
             context.session, pool.load_balancer_id)
@@ -158,6 +152,13 @@ class MemberController(base.BaseController):
         self._auth_validate_action(context, member.project_id,
                                    constants.RBAC_POST)
 
+        validate.ip_not_reserved(member.address)
+
+        # Validate member subnet
+        if (member.subnet_id and
+                not validate.subnet_exists(member.subnet_id, context=context)):
+            raise exceptions.NotFound(resource='Subnet', id=member.subnet_id)
+
         # Load the driver early as it also provides validation
         driver = driver_factory.get_driver(provider)
 
@@ -231,7 +232,6 @@ class MemberController(base.BaseController):
         context = pecan.request.context.get('octavia_context')
         db_member = self._get_db_member(context.session, id,
                                         show_deleted=False)
-
         pool = self.repositories.pool.get(context.session,
                                           id=db_member.pool_id)
         project_id, provider = self._get_lb_project_id_provider(
@@ -341,7 +341,7 @@ class MembersController(MemberController):
         # Validate member subnets
         for member in members:
             if member.subnet_id and not validate.subnet_exists(
-                    member.subnet_id):
+                    member.subnet_id, context=context):
                 raise exceptions.NotFound(resource='Subnet',
                                           id=member.subnet_id)
 
