@@ -12,6 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_config import cfg
 from wsme import types as wtypes
 
 from octavia.api.common import types
@@ -19,10 +20,16 @@ from octavia.api.v2.types import l7policy
 from octavia.api.v2.types import pool
 from octavia.common import constants
 
+CONF = cfg.CONF
+CONF.import_group('haproxy_amphora', 'octavia.common.config')
+
 
 class BaseListenerType(types.BaseType):
-    _type_to_model_map = {'admin_state_up': 'enabled',
-                          'default_tls_container_ref': 'tls_certificate_id'}
+    _type_to_model_map = {
+        'admin_state_up': 'enabled',
+        'default_tls_container_ref': 'tls_certificate_id',
+        'client_ca_tls_container_ref': 'client_ca_tls_certificate_id',
+        'client_crl_container_ref': 'client_crl_container_id'}
     _child_map = {}
 
 
@@ -46,6 +53,14 @@ class ListenerResponse(BaseListenerType):
     created_at = wtypes.wsattr(wtypes.datetime.datetime)
     updated_at = wtypes.wsattr(wtypes.datetime.datetime)
     loadbalancers = wtypes.wsattr([types.IdOnlyType])
+    timeout_client_data = wtypes.wsattr(wtypes.IntegerType())
+    timeout_member_connect = wtypes.wsattr(wtypes.IntegerType())
+    timeout_member_data = wtypes.wsattr(wtypes.IntegerType())
+    timeout_tcp_inspect = wtypes.wsattr(wtypes.IntegerType())
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType()))
+    client_ca_tls_container_ref = wtypes.StringType()
+    client_authentication = wtypes.wsattr(wtypes.StringType())
+    client_crl_container_ref = wtypes.wsattr(wtypes.StringType())
 
     @classmethod
     def from_data_model(cls, data_model, children=False):
@@ -54,7 +69,6 @@ class ListenerResponse(BaseListenerType):
 
         listener.sni_container_refs = [
             sni_c.tls_container_id for sni_c in data_model.sni_containers]
-
         if cls._full_response():
             del listener.loadbalancers
             l7policy_type = l7policy.L7PolicyFullResponse
@@ -110,6 +124,28 @@ class ListenerPOST(BaseListenerType):
     insert_headers = wtypes.wsattr(
         wtypes.DictType(str, wtypes.StringType(max_length=255)))
     loadbalancer_id = wtypes.wsattr(wtypes.UuidType(), mandatory=True)
+    timeout_client_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_client_data)
+    timeout_member_connect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_member_connect)
+    timeout_member_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_member_data)
+    timeout_tcp_inspect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_tcp_inspect)
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    client_ca_tls_container_ref = wtypes.StringType(max_length=255)
+    client_authentication = wtypes.wsattr(
+        wtypes.Enum(str, *constants.SUPPORTED_CLIENT_AUTH_MODES),
+        default=constants.CLIENT_AUTH_NONE)
+    client_crl_container_ref = wtypes.StringType(max_length=255)
 
 
 class ListenerRootPOST(types.BaseType):
@@ -129,6 +165,23 @@ class ListenerPUT(BaseListenerType):
     default_pool_id = wtypes.wsattr(wtypes.UuidType())
     insert_headers = wtypes.wsattr(
         wtypes.DictType(str, wtypes.StringType(max_length=255)))
+    timeout_client_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT))
+    timeout_member_connect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT))
+    timeout_member_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT))
+    timeout_tcp_inspect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT))
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    client_ca_tls_container_ref = wtypes.StringType(max_length=255)
+    client_authentication = wtypes.wsattr(
+        wtypes.Enum(str, *constants.SUPPORTED_CLIENT_AUTH_MODES))
+    client_crl_container_ref = wtypes.StringType(max_length=255)
 
 
 class ListenerRootPUT(types.BaseType):
@@ -156,6 +209,28 @@ class ListenerSingleCreate(BaseListenerType):
     l7policies = wtypes.wsattr([l7policy.L7PolicySingleCreate], default=[])
     insert_headers = wtypes.wsattr(
         wtypes.DictType(str, wtypes.StringType(max_length=255)))
+    timeout_client_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_client_data)
+    timeout_member_connect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_member_connect)
+    timeout_member_data = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_member_data)
+    timeout_tcp_inspect = wtypes.wsattr(
+        wtypes.IntegerType(minimum=constants.MIN_TIMEOUT,
+                           maximum=constants.MAX_TIMEOUT),
+        default=CONF.haproxy_amphora.timeout_tcp_inspect)
+    tags = wtypes.wsattr(wtypes.ArrayType(wtypes.StringType(max_length=255)))
+    client_ca_tls_container_ref = wtypes.StringType(max_length=255)
+    client_authentication = wtypes.wsattr(
+        wtypes.Enum(str, *constants.SUPPORTED_CLIENT_AUTH_MODES),
+        default=constants.CLIENT_AUTH_NONE)
+    client_crl_container_ref = wtypes.StringType(max_length=255)
 
 
 class ListenerStatusResponse(BaseListenerType):
