@@ -30,7 +30,7 @@ class Endpoint(object):
     #   1.0 - Initial version.
     target = messaging.Target(
         namespace=constants.RPC_NAMESPACE_CONTROLLER_AGENT,
-        version='1.0')
+        version='1.1')
 
     def __init__(self):
         self.worker = stevedore_driver.DriverManager(
@@ -39,9 +39,10 @@ class Endpoint(object):
             invoke_on_load=True
         ).driver
 
-    def create_load_balancer(self, context, load_balancer_id):
+    def create_load_balancer(self, context, load_balancer_id,
+                             flavor=None):
         LOG.info('Creating load balancer \'%s\'...', load_balancer_id)
-        self.worker.create_load_balancer(load_balancer_id)
+        self.worker.create_load_balancer(load_balancer_id, flavor)
 
     def update_load_balancer(self, context, load_balancer_id,
                              load_balancer_updates):
@@ -53,6 +54,16 @@ class Endpoint(object):
         LOG.info('Deleting load balancer \'%s\'...', load_balancer_id)
         self.worker.delete_load_balancer(load_balancer_id, cascade)
 
+    def failover_load_balancer(self, context, load_balancer_id):
+        LOG.info('Failing over amphora in load balancer \'%s\'...',
+                 load_balancer_id)
+        self.worker.failover_loadbalancer(load_balancer_id)
+
+    def failover_amphora(self, context, amphora_id):
+        LOG.info('Failing over amphora \'%s\'...',
+                 amphora_id)
+        self.worker.failover_amphora(amphora_id)
+
     def create_listener(self, context, listener_id):
         LOG.info('Creating listener \'%s\'...', listener_id)
         self.worker.create_listener(listener_id)
@@ -99,6 +110,17 @@ class Endpoint(object):
         LOG.info('Updating member \'%s\'...', member_id)
         self.worker.update_member(member_id, member_updates)
 
+    def batch_update_members(self, context, old_member_ids, new_member_ids,
+                             updated_members):
+        updated_member_ids = [m.get('id') for m in updated_members]
+        LOG.info(
+            'Batch updating members: old=\'%(old)s\', new=\'%(new)s\', '
+            'updated=\'%(updated)s\'...',
+            {'old': old_member_ids, 'new': new_member_ids,
+             'updated': updated_member_ids})
+        self.worker.batch_update_members(
+            old_member_ids, new_member_ids, updated_members)
+
     def delete_member(self, context, member_id):
         LOG.info('Deleting member \'%s\'...', member_id)
         self.worker.delete_member(member_id)
@@ -126,3 +148,8 @@ class Endpoint(object):
     def delete_l7rule(self, context, l7rule_id):
         LOG.info('Deleting l7rule \'%s\'...', l7rule_id)
         self.worker.delete_l7rule(l7rule_id)
+
+    def update_amphora_agent_config(self, context, amphora_id):
+        LOG.info('Updating amphora \'%s\' agent configuration...',
+                 amphora_id)
+        self.worker.update_amphora_agent_config(amphora_id)
