@@ -29,6 +29,7 @@ from octavia.common import constants
 from octavia.common import data_models
 import octavia.common.tls_utils.cert_parser as cert_parser
 from octavia.common import utils
+from octavia.common import validate
 from octavia.controller.worker import task_utils as task_utilities
 from octavia.db import api as db_apis
 from octavia.db import repositories as repo
@@ -410,7 +411,7 @@ class UpdateVIPAfterAllocation(BaseDatabaseTask):
                                             id=loadbalancer_id)
 
 
-class UpdateAmphoraVIPData(BaseDatabaseTask):
+class UpdateAmphoraeVIPData(BaseDatabaseTask):
     """Update amphorae VIP data."""
 
     def execute(self, amps_data):
@@ -428,6 +429,23 @@ class UpdateAmphoraVIPData(BaseDatabaseTask):
                                       vrrp_id=1)
 
 
+class UpdateAmphoraVIPData(BaseDatabaseTask):
+    """Update amphorae VIP data."""
+
+    def execute(self, amp_data):
+        """Update amphorae VIP data.
+
+        :param amps_data: Amphorae update dicts.
+        :returns: None
+        """
+        self.repos.amphora.update(db_apis.get_session(), amp_data.id,
+                                  vrrp_ip=amp_data.vrrp_ip,
+                                  ha_ip=amp_data.ha_ip,
+                                  vrrp_port_id=amp_data.vrrp_port_id,
+                                  ha_port_id=amp_data.ha_port_id,
+                                  vrrp_id=1)
+
+
 class UpdateAmpFailoverDetails(BaseDatabaseTask):
     """Update amphora failover details in the database."""
 
@@ -481,7 +499,7 @@ class AssociateFailoverAmphoraWithLBID(BaseDatabaseTask):
 class MapLoadbalancerToAmphora(BaseDatabaseTask):
     """Maps and assigns a load balancer to an amphora in the database."""
 
-    def execute(self, loadbalancer_id, server_group_id=None):
+    def execute(self, loadbalancer_id, server_group_id=None, flavor=None):
         """Allocates an Amphora for the load balancer in the database.
 
         :param loadbalancer_id: The load balancer id to map to an amphora
@@ -497,6 +515,13 @@ class MapLoadbalancerToAmphora(BaseDatabaseTask):
                       "pool allocation.")
             return None
 
+        # Validate the flavor is spares compatible
+        if not validate.is_flavor_spares_compatible(flavor):
+            LOG.debug("Load balancer has a flavor that is not compatible with "
+                      "using spares pool amphora. Skipping spares pool "
+                      "allocation.")
+            return None
+
         try:
             amp = self.amphora_repo.allocate_and_associate(
                 db_apis.get_session(),
@@ -885,7 +910,8 @@ class UpdateAmphoraInfo(BaseDatabaseTask):
             db_apis.get_session(), amphora_id,
             lb_network_ip=compute_obj.lb_network_ip,
             cached_zone=compute_obj.cached_zone,
-            image_id=compute_obj.image_id)
+            image_id=compute_obj.image_id,
+            compute_flavor=compute_obj.compute_flavor)
         return self.amphora_repo.get(db_apis.get_session(), id=amphora_id)
 
 
@@ -1157,14 +1183,14 @@ class MarkLBAndListenersActiveInDB(BaseDatabaseTask):
         """
 
         LOG.debug("Mark ACTIVE in DB for load balancer id: %s "
-                  "and listener ids: %s", loadbalancer.id,
+                  "and updating status for listener ids: %s", loadbalancer.id,
                   ', '.join([l.id for l in listeners]))
         self.loadbalancer_repo.update(db_apis.get_session(),
                                       loadbalancer.id,
                                       provisioning_status=constants.ACTIVE)
         for listener in listeners:
-            self.listener_repo.update(db_apis.get_session(), listener.id,
-                                      provisioning_status=constants.ACTIVE)
+            self.listener_repo.prov_status_active_if_not_error(
+                db_apis.get_session(), listener.id)
 
     def revert(self, loadbalancer, listeners, *args, **kwargs):
         """Mark the load balancer and listeners as broken.
@@ -1183,35 +1209,6 @@ class MarkLBAndListenersActiveInDB(BaseDatabaseTask):
             self.task_utils.mark_listener_prov_status_error(listener.id)
 
 
-class MarkListenerActiveInDB(BaseDatabaseTask):
-    """Mark the listener active in the DB.
-
-    Since sqlalchemy will likely retry by itself always revert if it fails
-    """
-
-    def execute(self, listener):
-        """Mark the listener as active in DB
-
-        :param listener: The listener to be marked active
-        :returns: None
-        """
-
-        LOG.debug("Mark ACTIVE in DB for listener id: %s ", listener.id)
-        self.listener_repo.update(db_apis.get_session(), listener.id,
-                                  provisioning_status=constants.ACTIVE)
-
-    def revert(self, listener, *args, **kwargs):
-        """Mark the listener ERROR since the delete couldn't happen
-
-        :param listener: The listener that couldn't be updated
-        :returns: None
-        """
-
-        LOG.warning("Reverting mark listener active in DB "
-                    "for listener id %s", listener.id)
-        self.task_utils.mark_listener_prov_status_error(listener.id)
-
-
 class MarkListenerDeletedInDB(BaseDatabaseTask):
     """Mark the listener deleted in the DB.
 
