@@ -30,9 +30,6 @@ Guidelines for writing new hacking checks
 
 """
 
-author_tag_re = (re.compile("^\s*#\s*@?(a|A)uthor"),
-                 re.compile("^\.\.\s+moduleauthor::"))
-
 _all_log_levels = {'critical', 'error', 'exception', 'info', 'warning'}
 _all_hints = {'_LC', '_LE', '_LI', '_', '_LW'}
 
@@ -69,6 +66,7 @@ no_basestring_re = re.compile(r"\bbasestring\b")
 no_iteritems_re = re.compile(r".*\.iteritems\(\)")
 no_eventlet_re = re.compile(r'(import|from)\s+[(]?eventlet')
 no_line_continuation_backslash_re = re.compile(r'.*(\\)\n')
+no_logging_re = re.compile(r'(import|from)\s+[(]?logging')
 
 
 def _translation_checks_not_enforced(filename):
@@ -82,7 +80,8 @@ def assert_true_instance(logical_line):
     O316
     """
     if assert_trueinst_re.match(logical_line):
-        yield (0, "O316: assertTrue(isinstance(a, b)) sentences not allowed")
+        yield (0, "O316: assertTrue(isinstance(a, b)) sentences not allowed. "
+               "Use assertIsInstance instead.")
 
 
 def assert_equal_or_not_none(logical_line):
@@ -102,16 +101,6 @@ def assert_equal_or_not_none(logical_line):
         yield (0, msg)
 
 
-def no_author_tags(physical_line):
-    for regex in author_tag_re:
-        if regex.match(physical_line):
-            physical_line = physical_line.lower()
-            pos = physical_line.find('moduleauthor')
-            if pos < 0:
-                pos = physical_line.find('author')
-            return pos, "O322: Don't use author tags"
-
-
 def assert_equal_true_or_false(logical_line):
     """Check for assertEqual(True, A) or assertEqual(False, A) sentences
 
@@ -287,11 +276,23 @@ def revert_must_have_kwargs(logical_line):
         yield 0, msg
 
 
+def check_no_logging_imports(logical_line):
+    """O348 - Usage of Python logging module not allowed.
+
+    :param logical_line: The logical line to check.
+    :returns: None if the logical line passes the check, otherwise a tuple
+              is yielded that contains the offending index in logical line
+              and a message describe the check validation failure.
+    """
+    if no_logging_re.match(logical_line):
+        msg = 'O348 Usage of Python logging module not allowed, use oslo_log'
+        yield logical_line.index('logging'), msg
+
+
 def factory(register):
     register(assert_true_instance)
     register(assert_equal_or_not_none)
     register(no_translate_logs)
-    register(no_author_tags)
     register(assert_equal_true_or_false)
     register(no_mutable_default_args)
     register(assert_equal_in)
@@ -303,3 +304,4 @@ def factory(register):
     register(check_no_eventlet_imports)
     register(check_line_continuation_no_backslash)
     register(revert_must_have_kwargs)
+    register(check_no_logging_imports)
