@@ -12,10 +12,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
 from oslo_db.sqlalchemy import test_base
 
+from octavia.common import config
 from octavia.common import constants
 from octavia.db import api as db_api
 from octavia.db import base_models
@@ -30,7 +30,7 @@ class OctaviaDBTestBase(test_base.DbTestCase):
         # session set up in the fixture for test_base.DbTestCase does not work
         # with the API functional tests.  Need to investigate more if this
         # becomes a problem
-        conf = self.useFixture(oslo_fixture.Config(cfg.CONF))
+        conf = self.useFixture(oslo_fixture.Config(config.cfg.CONF))
         conf.config(group="database", connection='sqlite://')
 
         # needed for closure
@@ -79,6 +79,8 @@ class OctaviaDBTestBase(test_base.DbTestCase):
                                 models.L7RuleCompareType)
         self._seed_lookup_table(session, constants.SUPPORTED_L7POLICY_ACTIONS,
                                 models.L7PolicyAction)
+        self._seed_lookup_table(session, constants.SUPPORTED_CLIENT_AUTH_MODES,
+                                models.ClientAuthenticationMode)
 
     def _seed_lookup_table(self, session, name_list, model_cls):
         for name in name_list:
