@@ -16,11 +16,16 @@
 import copy
 import os
 
+from oslo_config import cfg
+from oslo_config import fixture as oslo_fixture
+
 from octavia.common import constants
 from octavia.common.jinja.haproxy.split_listeners import jinja_cfg
 from octavia.tests.unit import base
 from octavia.tests.unit.common.sample_configs import sample_configs_split
 
+CONF = cfg.CONF
+
 
 class TestHaproxyCfg(base.TestCase):
     def setUp(self):
@@ -34,21 +39,25 @@ class TestHaproxyCfg(base.TestCase):
         self.assertEqual('haproxy.cfg.j2', template.name)
 
     def test_render_template_tls(self):
+        conf = oslo_fixture.Config(cfg.CONF)
+        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
+        FAKE_CRT_LIST_FILENAME = os.path.join(
+            CONF.haproxy_amphora.base_cert_dir,
+            'sample_listener_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
               "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
-              "ssl crt /var/lib/octavia/certs/"
-              "sample_listener_id_1/tls_container_id.pem "
-              "crt /var/lib/octavia/certs/sample_listener_id_1 "
+              "ssl crt-list {crt_list} "
               "ca-file /var/lib/octavia/certs/sample_listener_id_1/"
               "client_ca.pem verify required crl-file /var/lib/octavia/"
               "certs/sample_listener_id_1/SHA_ID.pem\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
               "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -67,16 +76,12 @@ class TestHaproxyCfg(base.TestCase):
               "weight 13 check inter 30s fall 3 rise 2 cookie "
               "sample_member_id_2\n\n").format(
             maxconn=constants.HAPROXY_MAX_MAXCONN)
-        tls_tupe = sample_configs_split.sample_tls_container_tuple(
-            id='tls_container_id',
-            certificate='imaCert1', private_key='imaPrivateKey1',
-            primary_cn='FakeCN')
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_split.sample_amphora_tuple(),
             sample_configs_split.sample_listener_tuple(
                 proto='TERMINATED_HTTPS', tls=True, sni=True,
                 client_ca_cert=True, client_crl_cert=True),
-            tls_tupe, client_ca_filename='client_ca.pem',
+            client_ca_filename='client_ca.pem',
             client_crl='SHA_ID.pem')
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(
@@ -84,17 +89,22 @@ class TestHaproxyCfg(base.TestCase):
             rendered_obj)
 
     def test_render_template_tls_no_sni(self):
+        conf = oslo_fixture.Config(cfg.CONF)
+        conf.config(group="haproxy_amphora", base_cert_dir='/fake_cert_dir')
+        FAKE_CRT_LIST_FILENAME = os.path.join(
+            CONF.haproxy_amphora.base_cert_dir,
+            'sample_listener_id_1/sample_listener_id_1.pem')
         fe = ("frontend sample_listener_id_1\n"
               "    option httplog\n"
               "    maxconn {maxconn}\n"
               "    redirect scheme https if !{{ ssl_fc }}\n"
               "    bind 10.0.0.2:443 "
-              "ssl crt /var/lib/octavia/certs/"
-              "sample_listener_id_1/tls_container_id.pem\n"
+              "ssl crt-list {crt_list}\n"
               "    mode http\n"
               "    default_backend sample_pool_id_1\n"
               "    timeout client 50000\n\n").format(
-            maxconn=constants.HAPROXY_MAX_MAXCONN)
+            maxconn=constants.HAPROXY_MAX_MAXCONN,
+            crt_list=FAKE_CRT_LIST_FILENAME)
         be = ("backend sample_pool_id_1\n"
               "    mode http\n"
               "    balance roundrobin\n"
@@ -116,12 +126,7 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = self.jinja_cfg.render_loadbalancer_obj(
             sample_configs_split.sample_amphora_tuple(),
             sample_configs_split.sample_listener_tuple(
-                proto='TERMINATED_HTTPS', tls=True),
-            tls_cert=sample_configs_split.sample_tls_container_tuple(
-                id='tls_container_id',
-                certificate='ImAalsdkfjCert',
-                private_key='ImAsdlfksdjPrivateKey',
-                primary_cn="FakeCN"))
+                proto='TERMINATED_HTTPS', tls=True))
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(
                 frontend=fe, backend=be),
@@ -899,19 +904,21 @@ class TestHaproxyCfg(base.TestCase):
 
     def test_transform_listener(self):
         in_listener = sample_configs_split.sample_listener_tuple()
-        ret = self.jinja_cfg._transform_listener(in_listener, None, {})
+        ret = self.jinja_cfg._transform_listener(in_listener, {},
+                                                 in_listener.load_balancer)
         self.assertEqual(sample_configs_split.RET_LISTENER, ret)
 
     def test_transform_listener_with_l7(self):
         in_listener = sample_configs_split.sample_listener_tuple(l7=True)
-        ret = self.jinja_cfg._transform_listener(in_listener, None, {})
+        ret = self.jinja_cfg._transform_listener(in_listener, {},
+                                                 in_listener.load_balancer)
         self.assertEqual(sample_configs_split.RET_LISTENER_L7, ret)
 
     def test_transform_loadbalancer(self):
         in_amphora = sample_configs_split.sample_amphora_tuple()
         in_listener = sample_configs_split.sample_listener_tuple()
         ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listener.load_balancer, in_listener, None, {})
+            in_amphora, in_listener.load_balancer, in_listener, {})
         self.assertEqual(sample_configs_split.RET_LB, ret)
 
     def test_transform_amphora(self):
@@ -923,7 +930,7 @@ class TestHaproxyCfg(base.TestCase):
         in_amphora = sample_configs_split.sample_amphora_tuple()
         in_listener = sample_configs_split.sample_listener_tuple(l7=True)
         ret = self.jinja_cfg._transform_loadbalancer(
-            in_amphora, in_listener.load_balancer, in_listener, None, {})
+            in_amphora, in_listener.load_balancer, in_listener, {})
         self.assertEqual(sample_configs_split.RET_LB_L7, ret)
 
     def test_transform_l7policy(self):
@@ -1036,7 +1043,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_configs_split.sample_amphora_tuple(),
             sample_configs_split.sample_listener_tuple(be_proto='PROXY'),
-            tls_cert=None,
             haproxy_versions=("1", "8", "1"))
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(backend=be),
@@ -1062,7 +1068,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_configs_split.sample_amphora_tuple(),
             sample_configs_split.sample_listener_tuple(be_proto='PROXY'),
-            tls_cert=None,
             haproxy_versions=("1", "5", "18"))
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(backend=be),
@@ -1144,7 +1149,6 @@ class TestHaproxyCfg(base.TestCase):
         rendered_obj = j_cfg.build_config(
             sample_configs_split.sample_amphora_tuple(),
             sample_listener,
-            tls_cert=None,
             haproxy_versions=("1", "5", "18"))
         self.assertEqual(
             sample_configs_split.sample_base_expected_config(
