@@ -16,7 +16,7 @@
 from octavia.common import constants
 from octavia.common.jinja.lvs import jinja_cfg
 from octavia.tests.unit import base
-from octavia.tests.unit.common.sample_configs import sample_configs
+from octavia.tests.unit.common.sample_configs import sample_configs_combined
 
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
@@ -46,7 +46,7 @@ class TestLvsCfg(base.TestCase):
                "    persistence_timeout 33\n"
                "    persistence_granularity 255.255.0.0\n"
                "    delay_loop 30\n"
-               "    delay_before_retry 31\n"
+               "    delay_before_retry 30\n"
                "    retry 3\n\n\n"
                "    # Configuration for Pool sample_pool_id_1\n"
                "    # Configuration for HealthMonitor sample_monitor_id_1\n"
@@ -54,29 +54,25 @@ class TestLvsCfg(base.TestCase):
                "    real_server 10.0.0.99 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.99 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "    # Configuration for Member sample_member_id_2\n"
                "    real_server 10.0.0.98 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.98 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "}\n\n")
         rendered_obj = self.udp_jinja_cfg.render_loadbalancer_obj(
-            sample_configs.sample_listener_tuple(
+            sample_configs_combined.sample_listener_tuple(
                 proto=constants.PROTOCOL_UDP,
                 persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
                 persistence_timeout=33,
@@ -94,7 +90,7 @@ class TestLvsCfg(base.TestCase):
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
-               "    delay_before_retry 31\n"
+               "    delay_before_retry 30\n"
                "    retry 3\n\n\n"
                "    # Configuration for Pool sample_pool_id_1\n"
                "    # Configuration for HealthMonitor sample_monitor_id_1\n"
@@ -102,29 +98,25 @@ class TestLvsCfg(base.TestCase):
                "    real_server 10.0.0.99 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.99 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "    # Configuration for Member sample_member_id_2\n"
                "    real_server 10.0.0.98 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.98 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "}\n\n")
 
-        listener = sample_configs.sample_listener_tuple(
+        listener = sample_configs_combined.sample_listener_tuple(
             proto=constants.PROTOCOL_UDP,
             monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT,
             connection_limit=98,
@@ -141,7 +133,7 @@ class TestLvsCfg(base.TestCase):
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
-               "    delay_before_retry 31\n"
+               "    delay_before_retry 30\n"
                "    retry 3\n\n\n"
                "    # Configuration for Pool sample_pool_id_1\n"
                "    # Configuration for HealthMonitor sample_monitor_id_1\n"
@@ -149,30 +141,26 @@ class TestLvsCfg(base.TestCase):
                "    real_server 10.0.0.99 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.99 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "    # Configuration for Member sample_member_id_2\n"
                "    real_server 10.0.0.98 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 10.0.0.98 82\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "}\n\n")
 
         rendered_obj = self.udp_jinja_cfg.render_loadbalancer_obj(
-            sample_configs.sample_listener_tuple(
+            sample_configs_combined.sample_listener_tuple(
                 proto=constants.PROTOCOL_UDP,
                 monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT,
                 persistence=False,
@@ -188,7 +176,7 @@ class TestLvsCfg(base.TestCase):
                "    lb_kind NAT\n"
                "    protocol UDP\n"
                "    delay_loop 30\n"
-               "    delay_before_retry 31\n"
+               "    delay_before_retry 30\n"
                "    retry 3\n\n\n"
                "    # Configuration for Pool sample_pool_id_1\n"
                "    # Configuration for HealthMonitor sample_monitor_id_1\n"
@@ -196,30 +184,26 @@ class TestLvsCfg(base.TestCase):
                "    real_server 10.0.0.99 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 192.168.1.1 9000\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "    # Configuration for Member sample_member_id_2\n"
                "    real_server 10.0.0.98 82 {\n"
                "        weight 13\n"
                "        uthreshold 98\n"
-               "        delay_before_retry 31\n"
-               "        retry 3\n"
                "        MISC_CHECK {\n"
                "            misc_path \"/var/lib/octavia/lvs/check/"
                "udp_check.sh 192.168.1.1 9000\"\n"
-               "            misc_timeout 30\n"
+               "            misc_timeout 31\n"
                "        }\n"
                "    }\n\n"
                "}\n\n")
 
         rendered_obj = self.udp_jinja_cfg.render_loadbalancer_obj(
-            sample_configs.sample_listener_tuple(
+            sample_configs_combined.sample_listener_tuple(
                 proto=constants.PROTOCOL_UDP,
                 monitor_ip_port=True,
                 monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT,
@@ -233,64 +217,65 @@ class TestLvsCfg(base.TestCase):
                "net_namespace amphora-haproxy\n\n\n")
 
         rendered_obj = self.udp_jinja_cfg.render_loadbalancer_obj(
-            sample_configs.sample_listener_tuple(
+            sample_configs_combined.sample_listener_tuple(
                 proto=constants.PROTOCOL_UDP, monitor=False,
                 persistence=False, alloc_default_pool=False))
         self.assertEqual(exp, rendered_obj)
 
     def test_udp_transform_session_persistence(self):
-        persistence_src_ip = sample_configs.sample_session_persistence_tuple(
-            persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
-            persistence_cookie=None,
-            persistence_timeout=33,
-            persistence_granularity='255.0.0.0'
-        )
-        exp = sample_configs.UDP_SOURCE_IP_BODY
+        persistence_src_ip = (
+            sample_configs_combined.sample_session_persistence_tuple(
+                persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
+                persistence_cookie=None,
+                persistence_timeout=33,
+                persistence_granularity='255.0.0.0'
+            ))
+        exp = sample_configs_combined.UDP_SOURCE_IP_BODY
         ret = self.udp_jinja_cfg._transform_session_persistence(
             persistence_src_ip)
         self.assertEqual(exp, ret)
 
     def test_udp_transform_health_monitor(self):
-        in_hm = sample_configs.sample_health_monitor_tuple(
+        in_hm = sample_configs_combined.sample_health_monitor_tuple(
             proto=constants.HEALTH_MONITOR_UDP_CONNECT
         )
         ret = self.udp_jinja_cfg._transform_health_monitor(in_hm)
-        self.assertEqual(sample_configs.RET_UDP_HEALTH_MONITOR, ret)
+        self.assertEqual(sample_configs_combined.RET_UDP_HEALTH_MONITOR, ret)
 
     def test_udp_transform_member(self):
-        in_member = sample_configs.sample_member_tuple('member_id_1',
-                                                       '192.0.2.10')
+        in_member = sample_configs_combined.sample_member_tuple(
+            'member_id_1', '192.0.2.10')
         ret = self.udp_jinja_cfg._transform_member(in_member)
-        self.assertEqual(sample_configs.RET_UDP_MEMBER, ret)
+        self.assertEqual(sample_configs_combined.RET_UDP_MEMBER, ret)
 
-        in_member = sample_configs.sample_member_tuple(
+        in_member = sample_configs_combined.sample_member_tuple(
             'member_id_1',
             '192.0.2.10',
             monitor_ip_port=True)
         ret = self.udp_jinja_cfg._transform_member(in_member)
         self.assertEqual(
-            sample_configs.RET_UDP_MEMBER_MONITOR_IP_PORT, ret)
+            sample_configs_combined.RET_UDP_MEMBER_MONITOR_IP_PORT, ret)
 
     def test_udp_transform_pool(self):
-        in_pool = sample_configs.sample_pool_tuple(
+        in_pool = sample_configs_combined.sample_pool_tuple(
             proto=constants.PROTOCOL_UDP,
             persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
             persistence_timeout=33, persistence_granularity='255.0.0.0',
         )
         ret = self.udp_jinja_cfg._transform_pool(in_pool)
-        self.assertEqual(sample_configs.RET_UDP_POOL, ret)
+        self.assertEqual(sample_configs_combined.RET_UDP_POOL, ret)
 
-        in_pool = sample_configs.sample_pool_tuple(
+        in_pool = sample_configs_combined.sample_pool_tuple(
             proto=constants.PROTOCOL_UDP,
             persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
             persistence_timeout=33, persistence_granularity='255.0.0.0',
             monitor=False)
-        sample_configs.RET_UDP_POOL['health_monitor'] = ''
+        sample_configs_combined.RET_UDP_POOL['health_monitor'] = ''
         ret = self.udp_jinja_cfg._transform_pool(in_pool)
-        self.assertEqual(sample_configs.RET_UDP_POOL, ret)
+        self.assertEqual(sample_configs_combined.RET_UDP_POOL, ret)
 
     def test_udp_transform_listener(self):
-        in_listener = sample_configs.sample_listener_tuple(
+        in_listener = sample_configs_combined.sample_listener_tuple(
             proto=constants.PROTOCOL_UDP,
             persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
             persistence_timeout=33,
@@ -299,9 +284,9 @@ class TestLvsCfg(base.TestCase):
             connection_limit=98
         )
         ret = self.udp_jinja_cfg._transform_listener(in_listener)
-        self.assertEqual(sample_configs.RET_UDP_LISTENER, ret)
+        self.assertEqual(sample_configs_combined.RET_UDP_LISTENER, ret)
 
-        in_listener = sample_configs.sample_listener_tuple(
+        in_listener = sample_configs_combined.sample_listener_tuple(
             proto=constants.PROTOCOL_UDP,
             persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
             persistence_timeout=33,
@@ -310,5 +295,20 @@ class TestLvsCfg(base.TestCase):
             connection_limit=-1)
 
         ret = self.udp_jinja_cfg._transform_listener(in_listener)
-        sample_configs.RET_UDP_LISTENER.pop('connection_limit')
-        self.assertEqual(sample_configs.RET_UDP_LISTENER, ret)
+        sample_configs_combined.RET_UDP_LISTENER.pop('connection_limit')
+        self.assertEqual(sample_configs_combined.RET_UDP_LISTENER, ret)
+
+    def test_render_template_disabled_udp_listener(self):
+        exp = ("# Configuration for Loadbalancer sample_loadbalancer_id_1\n"
+               "# Listener sample_listener_id_1 is disabled\n\n"
+               "net_namespace amphora-haproxy\n\n")
+        rendered_obj = self.udp_jinja_cfg.render_loadbalancer_obj(
+            sample_configs_combined.sample_listener_tuple(
+                enabled=False,
+                proto=constants.PROTOCOL_UDP,
+                persistence_type=constants.SESSION_PERSISTENCE_SOURCE_IP,
+                persistence_timeout=33,
+                persistence_granularity='255.255.0.0',
+                monitor_proto=constants.HEALTH_MONITOR_UDP_CONNECT,
+                connection_limit=98))
+        self.assertEqual(exp, rendered_obj)
