@@ -15,6 +15,7 @@
 import mock
 from oslo_config import cfg
 from oslo_config import fixture as oslo_fixture
+from oslo_utils import uuidutils
 
 from octavia.controller.queue import endpoint
 from octavia.controller.worker import controller_worker
@@ -39,11 +40,18 @@ class TestEndpoint(base.TestCase):
         self.resource_updates = {}
         self.resource_id = 1234
         self.server_group_id = 3456
+        self.flavor_id = uuidutils.generate_uuid()
 
     def test_create_load_balancer(self):
+        self.ep.create_load_balancer(self.context, self.resource_id,
+                                     flavor=self.flavor_id)
+        self.ep.worker.create_load_balancer.assert_called_once_with(
+            self.resource_id, self.flavor_id)
+
+    def test_create_load_balancer_no_flavor(self):
         self.ep.create_load_balancer(self.context, self.resource_id)
         self.ep.worker.create_load_balancer.assert_called_once_with(
-            self.resource_id)
+            self.resource_id, None)
 
     def test_update_load_balancer(self):
         self.ep.update_load_balancer(self.context, self.resource_id,
@@ -56,6 +64,16 @@ class TestEndpoint(base.TestCase):
         self.ep.worker.delete_load_balancer.assert_called_once_with(
             self.resource_id, False)
 
+    def test_failover_load_balancer(self):
+        self.ep.failover_load_balancer(self.context, self.resource_id)
+        self.ep.worker.failover_loadbalancer.assert_called_once_with(
+            self.resource_id)
+
+    def test_failover_amphora(self):
+        self.ep.failover_amphora(self.context, self.resource_id)
+        self.ep.worker.failover_amphora.assert_called_once_with(
+            self.resource_id)
+
     def test_create_listener(self):
         self.ep.create_listener(self.context, self.resource_id)
         self.ep.worker.create_listener.assert_called_once_with(
@@ -115,6 +133,12 @@ class TestEndpoint(base.TestCase):
         self.ep.worker.update_member.assert_called_once_with(
             self.resource_id, self.resource_updates)
 
+    def test_batch_update_members(self):
+        self.ep.batch_update_members(
+            self.context, [9], [11], [self.resource_updates])
+        self.ep.worker.batch_update_members.assert_called_once_with(
+            [9], [11], [self.resource_updates])
+
     def test_delete_member(self):
         self.ep.delete_member(self.context, self.resource_id)
         self.ep.worker.delete_member.assert_called_once_with(
@@ -151,3 +175,8 @@ class TestEndpoint(base.TestCase):
         self.ep.delete_l7rule(self.context, self.resource_id)
         self.ep.worker.delete_l7rule.assert_called_once_with(
             self.resource_id)
+
+    def test_update_amphora_agent_config(self):
+        self.ep.update_amphora_agent_config(self.context, self.resource_id)
+        self.ep.worker.update_amphora_agent_config.assert_called_once_with(
+            self.resource_id)
